#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOverseasFundInstitutionschoolinfCreateModel(object):

    def __init__(self):
        self._attr_code = None
        self._bussess_adr = None
        self._city_code = None
        self._city_name = None
        self._country_code = None
        self._cust_type = None
        self._declare_type = None
        self._district_code = None
        self._district_name = None
        self._economy_type_code = None
        self._ext_info = None
        self._investment_country_code_one = None
        self._is_special_economic_zone = None
        self._isv_name = None
        self._isv_phone = None
        self._isv_request_no = None
        self._link_man_name = None
        self._link_phone = None
        self._office_adr_en = None
        self._org_name_en = None
        self._org_type = None
        self._province_code = None
        self._province_name = None
        self._remark_info = None
        self._school_address = None
        self._school_country = None
        self._school_en_name = None
        self._school_icon = None
        self._school_icon_type = None
        self._school_mcc = None
        self._school_name = None
        self._school_pid = None
        self._school_stdcode = None
        self._school_type = None
        self._school_zipcode = None
        self._special_economic_zone_company_type = None
        self._trans_email = None

    @property
    def attr_code(self):
        return self._attr_code

    @attr_code.setter
    def attr_code(self, value):
        self._attr_code = value
    @property
    def bussess_adr(self):
        return self._bussess_adr

    @bussess_adr.setter
    def bussess_adr(self, value):
        self._bussess_adr = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def country_code(self):
        return self._country_code

    @country_code.setter
    def country_code(self, value):
        self._country_code = value
    @property
    def cust_type(self):
        return self._cust_type

    @cust_type.setter
    def cust_type(self, value):
        self._cust_type = value
    @property
    def declare_type(self):
        return self._declare_type

    @declare_type.setter
    def declare_type(self, value):
        self._declare_type = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def district_name(self):
        return self._district_name

    @district_name.setter
    def district_name(self, value):
        self._district_name = value
    @property
    def economy_type_code(self):
        return self._economy_type_code

    @economy_type_code.setter
    def economy_type_code(self, value):
        self._economy_type_code = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def investment_country_code_one(self):
        return self._investment_country_code_one

    @investment_country_code_one.setter
    def investment_country_code_one(self, value):
        self._investment_country_code_one = value
    @property
    def is_special_economic_zone(self):
        return self._is_special_economic_zone

    @is_special_economic_zone.setter
    def is_special_economic_zone(self, value):
        self._is_special_economic_zone = value
    @property
    def isv_name(self):
        return self._isv_name

    @isv_name.setter
    def isv_name(self, value):
        self._isv_name = value
    @property
    def isv_phone(self):
        return self._isv_phone

    @isv_phone.setter
    def isv_phone(self, value):
        self._isv_phone = value
    @property
    def isv_request_no(self):
        return self._isv_request_no

    @isv_request_no.setter
    def isv_request_no(self, value):
        self._isv_request_no = value
    @property
    def link_man_name(self):
        return self._link_man_name

    @link_man_name.setter
    def link_man_name(self, value):
        self._link_man_name = value
    @property
    def link_phone(self):
        return self._link_phone

    @link_phone.setter
    def link_phone(self, value):
        self._link_phone = value
    @property
    def office_adr_en(self):
        return self._office_adr_en

    @office_adr_en.setter
    def office_adr_en(self, value):
        self._office_adr_en = value
    @property
    def org_name_en(self):
        return self._org_name_en

    @org_name_en.setter
    def org_name_en(self, value):
        self._org_name_en = value
    @property
    def org_type(self):
        return self._org_type

    @org_type.setter
    def org_type(self, value):
        self._org_type = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def province_name(self):
        return self._province_name

    @province_name.setter
    def province_name(self, value):
        self._province_name = value
    @property
    def remark_info(self):
        return self._remark_info

    @remark_info.setter
    def remark_info(self, value):
        self._remark_info = value
    @property
    def school_address(self):
        return self._school_address

    @school_address.setter
    def school_address(self, value):
        self._school_address = value
    @property
    def school_country(self):
        return self._school_country

    @school_country.setter
    def school_country(self, value):
        self._school_country = value
    @property
    def school_en_name(self):
        return self._school_en_name

    @school_en_name.setter
    def school_en_name(self, value):
        self._school_en_name = value
    @property
    def school_icon(self):
        return self._school_icon

    @school_icon.setter
    def school_icon(self, value):
        self._school_icon = value
    @property
    def school_icon_type(self):
        return self._school_icon_type

    @school_icon_type.setter
    def school_icon_type(self, value):
        self._school_icon_type = value
    @property
    def school_mcc(self):
        return self._school_mcc

    @school_mcc.setter
    def school_mcc(self, value):
        self._school_mcc = value
    @property
    def school_name(self):
        return self._school_name

    @school_name.setter
    def school_name(self, value):
        self._school_name = value
    @property
    def school_pid(self):
        return self._school_pid

    @school_pid.setter
    def school_pid(self, value):
        self._school_pid = value
    @property
    def school_stdcode(self):
        return self._school_stdcode

    @school_stdcode.setter
    def school_stdcode(self, value):
        self._school_stdcode = value
    @property
    def school_type(self):
        return self._school_type

    @school_type.setter
    def school_type(self, value):
        self._school_type = value
    @property
    def school_zipcode(self):
        return self._school_zipcode

    @school_zipcode.setter
    def school_zipcode(self, value):
        self._school_zipcode = value
    @property
    def special_economic_zone_company_type(self):
        return self._special_economic_zone_company_type

    @special_economic_zone_company_type.setter
    def special_economic_zone_company_type(self, value):
        self._special_economic_zone_company_type = value
    @property
    def trans_email(self):
        return self._trans_email

    @trans_email.setter
    def trans_email(self, value):
        self._trans_email = value


    def to_alipay_dict(self):
        params = dict()
        if self.attr_code:
            if hasattr(self.attr_code, 'to_alipay_dict'):
                params['attr_code'] = self.attr_code.to_alipay_dict()
            else:
                params['attr_code'] = self.attr_code
        if self.bussess_adr:
            if hasattr(self.bussess_adr, 'to_alipay_dict'):
                params['bussess_adr'] = self.bussess_adr.to_alipay_dict()
            else:
                params['bussess_adr'] = self.bussess_adr
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.country_code:
            if hasattr(self.country_code, 'to_alipay_dict'):
                params['country_code'] = self.country_code.to_alipay_dict()
            else:
                params['country_code'] = self.country_code
        if self.cust_type:
            if hasattr(self.cust_type, 'to_alipay_dict'):
                params['cust_type'] = self.cust_type.to_alipay_dict()
            else:
                params['cust_type'] = self.cust_type
        if self.declare_type:
            if hasattr(self.declare_type, 'to_alipay_dict'):
                params['declare_type'] = self.declare_type.to_alipay_dict()
            else:
                params['declare_type'] = self.declare_type
        if self.district_code:
            if hasattr(self.district_code, 'to_alipay_dict'):
                params['district_code'] = self.district_code.to_alipay_dict()
            else:
                params['district_code'] = self.district_code
        if self.district_name:
            if hasattr(self.district_name, 'to_alipay_dict'):
                params['district_name'] = self.district_name.to_alipay_dict()
            else:
                params['district_name'] = self.district_name
        if self.economy_type_code:
            if hasattr(self.economy_type_code, 'to_alipay_dict'):
                params['economy_type_code'] = self.economy_type_code.to_alipay_dict()
            else:
                params['economy_type_code'] = self.economy_type_code
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.investment_country_code_one:
            if hasattr(self.investment_country_code_one, 'to_alipay_dict'):
                params['investment_country_code_one'] = self.investment_country_code_one.to_alipay_dict()
            else:
                params['investment_country_code_one'] = self.investment_country_code_one
        if self.is_special_economic_zone:
            if hasattr(self.is_special_economic_zone, 'to_alipay_dict'):
                params['is_special_economic_zone'] = self.is_special_economic_zone.to_alipay_dict()
            else:
                params['is_special_economic_zone'] = self.is_special_economic_zone
        if self.isv_name:
            if hasattr(self.isv_name, 'to_alipay_dict'):
                params['isv_name'] = self.isv_name.to_alipay_dict()
            else:
                params['isv_name'] = self.isv_name
        if self.isv_phone:
            if hasattr(self.isv_phone, 'to_alipay_dict'):
                params['isv_phone'] = self.isv_phone.to_alipay_dict()
            else:
                params['isv_phone'] = self.isv_phone
        if self.isv_request_no:
            if hasattr(self.isv_request_no, 'to_alipay_dict'):
                params['isv_request_no'] = self.isv_request_no.to_alipay_dict()
            else:
                params['isv_request_no'] = self.isv_request_no
        if self.link_man_name:
            if hasattr(self.link_man_name, 'to_alipay_dict'):
                params['link_man_name'] = self.link_man_name.to_alipay_dict()
            else:
                params['link_man_name'] = self.link_man_name
        if self.link_phone:
            if hasattr(self.link_phone, 'to_alipay_dict'):
                params['link_phone'] = self.link_phone.to_alipay_dict()
            else:
                params['link_phone'] = self.link_phone
        if self.office_adr_en:
            if hasattr(self.office_adr_en, 'to_alipay_dict'):
                params['office_adr_en'] = self.office_adr_en.to_alipay_dict()
            else:
                params['office_adr_en'] = self.office_adr_en
        if self.org_name_en:
            if hasattr(self.org_name_en, 'to_alipay_dict'):
                params['org_name_en'] = self.org_name_en.to_alipay_dict()
            else:
                params['org_name_en'] = self.org_name_en
        if self.org_type:
            if hasattr(self.org_type, 'to_alipay_dict'):
                params['org_type'] = self.org_type.to_alipay_dict()
            else:
                params['org_type'] = self.org_type
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.province_name:
            if hasattr(self.province_name, 'to_alipay_dict'):
                params['province_name'] = self.province_name.to_alipay_dict()
            else:
                params['province_name'] = self.province_name
        if self.remark_info:
            if hasattr(self.remark_info, 'to_alipay_dict'):
                params['remark_info'] = self.remark_info.to_alipay_dict()
            else:
                params['remark_info'] = self.remark_info
        if self.school_address:
            if hasattr(self.school_address, 'to_alipay_dict'):
                params['school_address'] = self.school_address.to_alipay_dict()
            else:
                params['school_address'] = self.school_address
        if self.school_country:
            if hasattr(self.school_country, 'to_alipay_dict'):
                params['school_country'] = self.school_country.to_alipay_dict()
            else:
                params['school_country'] = self.school_country
        if self.school_en_name:
            if hasattr(self.school_en_name, 'to_alipay_dict'):
                params['school_en_name'] = self.school_en_name.to_alipay_dict()
            else:
                params['school_en_name'] = self.school_en_name
        if self.school_icon:
            if hasattr(self.school_icon, 'to_alipay_dict'):
                params['school_icon'] = self.school_icon.to_alipay_dict()
            else:
                params['school_icon'] = self.school_icon
        if self.school_icon_type:
            if hasattr(self.school_icon_type, 'to_alipay_dict'):
                params['school_icon_type'] = self.school_icon_type.to_alipay_dict()
            else:
                params['school_icon_type'] = self.school_icon_type
        if self.school_mcc:
            if hasattr(self.school_mcc, 'to_alipay_dict'):
                params['school_mcc'] = self.school_mcc.to_alipay_dict()
            else:
                params['school_mcc'] = self.school_mcc
        if self.school_name:
            if hasattr(self.school_name, 'to_alipay_dict'):
                params['school_name'] = self.school_name.to_alipay_dict()
            else:
                params['school_name'] = self.school_name
        if self.school_pid:
            if hasattr(self.school_pid, 'to_alipay_dict'):
                params['school_pid'] = self.school_pid.to_alipay_dict()
            else:
                params['school_pid'] = self.school_pid
        if self.school_stdcode:
            if hasattr(self.school_stdcode, 'to_alipay_dict'):
                params['school_stdcode'] = self.school_stdcode.to_alipay_dict()
            else:
                params['school_stdcode'] = self.school_stdcode
        if self.school_type:
            if hasattr(self.school_type, 'to_alipay_dict'):
                params['school_type'] = self.school_type.to_alipay_dict()
            else:
                params['school_type'] = self.school_type
        if self.school_zipcode:
            if hasattr(self.school_zipcode, 'to_alipay_dict'):
                params['school_zipcode'] = self.school_zipcode.to_alipay_dict()
            else:
                params['school_zipcode'] = self.school_zipcode
        if self.special_economic_zone_company_type:
            if hasattr(self.special_economic_zone_company_type, 'to_alipay_dict'):
                params['special_economic_zone_company_type'] = self.special_economic_zone_company_type.to_alipay_dict()
            else:
                params['special_economic_zone_company_type'] = self.special_economic_zone_company_type
        if self.trans_email:
            if hasattr(self.trans_email, 'to_alipay_dict'):
                params['trans_email'] = self.trans_email.to_alipay_dict()
            else:
                params['trans_email'] = self.trans_email
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasFundInstitutionschoolinfCreateModel()
        if 'attr_code' in d:
            o.attr_code = d['attr_code']
        if 'bussess_adr' in d:
            o.bussess_adr = d['bussess_adr']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'country_code' in d:
            o.country_code = d['country_code']
        if 'cust_type' in d:
            o.cust_type = d['cust_type']
        if 'declare_type' in d:
            o.declare_type = d['declare_type']
        if 'district_code' in d:
            o.district_code = d['district_code']
        if 'district_name' in d:
            o.district_name = d['district_name']
        if 'economy_type_code' in d:
            o.economy_type_code = d['economy_type_code']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'investment_country_code_one' in d:
            o.investment_country_code_one = d['investment_country_code_one']
        if 'is_special_economic_zone' in d:
            o.is_special_economic_zone = d['is_special_economic_zone']
        if 'isv_name' in d:
            o.isv_name = d['isv_name']
        if 'isv_phone' in d:
            o.isv_phone = d['isv_phone']
        if 'isv_request_no' in d:
            o.isv_request_no = d['isv_request_no']
        if 'link_man_name' in d:
            o.link_man_name = d['link_man_name']
        if 'link_phone' in d:
            o.link_phone = d['link_phone']
        if 'office_adr_en' in d:
            o.office_adr_en = d['office_adr_en']
        if 'org_name_en' in d:
            o.org_name_en = d['org_name_en']
        if 'org_type' in d:
            o.org_type = d['org_type']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'province_name' in d:
            o.province_name = d['province_name']
        if 'remark_info' in d:
            o.remark_info = d['remark_info']
        if 'school_address' in d:
            o.school_address = d['school_address']
        if 'school_country' in d:
            o.school_country = d['school_country']
        if 'school_en_name' in d:
            o.school_en_name = d['school_en_name']
        if 'school_icon' in d:
            o.school_icon = d['school_icon']
        if 'school_icon_type' in d:
            o.school_icon_type = d['school_icon_type']
        if 'school_mcc' in d:
            o.school_mcc = d['school_mcc']
        if 'school_name' in d:
            o.school_name = d['school_name']
        if 'school_pid' in d:
            o.school_pid = d['school_pid']
        if 'school_stdcode' in d:
            o.school_stdcode = d['school_stdcode']
        if 'school_type' in d:
            o.school_type = d['school_type']
        if 'school_zipcode' in d:
            o.school_zipcode = d['school_zipcode']
        if 'special_economic_zone_company_type' in d:
            o.special_economic_zone_company_type = d['special_economic_zone_company_type']
        if 'trans_email' in d:
            o.trans_email = d['trans_email']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingActivityOrdervoucherSendModel(object):

    def __init__(self):
        self._activity_id = None
        self._biz_dt = None
        self._ch_info = None
        self._merchant_order_url = None
        self._open_id = None
        self._out_biz_no = None
        self._trade_channel = None
        self._trade_no = None
        self._user_id = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def biz_dt(self):
        return self._biz_dt

    @biz_dt.setter
    def biz_dt(self, value):
        self._biz_dt = value
    @property
    def ch_info(self):
        return self._ch_info

    @ch_info.setter
    def ch_info(self, value):
        self._ch_info = value
    @property
    def merchant_order_url(self):
        return self._merchant_order_url

    @merchant_order_url.setter
    def merchant_order_url(self, value):
        self._merchant_order_url = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def trade_channel(self):
        return self._trade_channel

    @trade_channel.setter
    def trade_channel(self, value):
        self._trade_channel = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.biz_dt:
            if hasattr(self.biz_dt, 'to_alipay_dict'):
                params['biz_dt'] = self.biz_dt.to_alipay_dict()
            else:
                params['biz_dt'] = self.biz_dt
        if self.ch_info:
            if hasattr(self.ch_info, 'to_alipay_dict'):
                params['ch_info'] = self.ch_info.to_alipay_dict()
            else:
                params['ch_info'] = self.ch_info
        if self.merchant_order_url:
            if hasattr(self.merchant_order_url, 'to_alipay_dict'):
                params['merchant_order_url'] = self.merchant_order_url.to_alipay_dict()
            else:
                params['merchant_order_url'] = self.merchant_order_url
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.trade_channel:
            if hasattr(self.trade_channel, 'to_alipay_dict'):
                params['trade_channel'] = self.trade_channel.to_alipay_dict()
            else:
                params['trade_channel'] = self.trade_channel
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivityOrdervoucherSendModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'biz_dt' in d:
            o.biz_dt = d['biz_dt']
        if 'ch_info' in d:
            o.ch_info = d['ch_info']
        if 'merchant_order_url' in d:
            o.merchant_order_url = d['merchant_order_url']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'trade_channel' in d:
            o.trade_channel = d['trade_channel']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceIotDeviceBaseinfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotDeviceBaseinfoQueryResponse, self).__init__()
        self._device_id = None

    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotDeviceBaseinfoQueryResponse, self).parse_response_content(response_content)
        if 'device_id' in response:
            self.device_id = response['device_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BkdfmacBizActionConsumedAmountDTO import BkdfmacBizActionConsumedAmountDTO


class BkdfmacBizActionConsumedAmountsDTO(object):

    def __init__(self):
        self._biz_action_consumed_amount_list = None
        self._biz_uk_id = None

    @property
    def biz_action_consumed_amount_list(self):
        return self._biz_action_consumed_amount_list

    @biz_action_consumed_amount_list.setter
    def biz_action_consumed_amount_list(self, value):
        if isinstance(value, list):
            self._biz_action_consumed_amount_list = list()
            for i in value:
                if isinstance(i, BkdfmacBizActionConsumedAmountDTO):
                    self._biz_action_consumed_amount_list.append(i)
                else:
                    self._biz_action_consumed_amount_list.append(BkdfmacBizActionConsumedAmountDTO.from_alipay_dict(i))
    @property
    def biz_uk_id(self):
        return self._biz_uk_id

    @biz_uk_id.setter
    def biz_uk_id(self, value):
        self._biz_uk_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_action_consumed_amount_list:
            if isinstance(self.biz_action_consumed_amount_list, list):
                for i in range(0, len(self.biz_action_consumed_amount_list)):
                    element = self.biz_action_consumed_amount_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.biz_action_consumed_amount_list[i] = element.to_alipay_dict()
            if hasattr(self.biz_action_consumed_amount_list, 'to_alipay_dict'):
                params['biz_action_consumed_amount_list'] = self.biz_action_consumed_amount_list.to_alipay_dict()
            else:
                params['biz_action_consumed_amount_list'] = self.biz_action_consumed_amount_list
        if self.biz_uk_id:
            if hasattr(self.biz_uk_id, 'to_alipay_dict'):
                params['biz_uk_id'] = self.biz_uk_id.to_alipay_dict()
            else:
                params['biz_uk_id'] = self.biz_uk_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BkdfmacBizActionConsumedAmountsDTO()
        if 'biz_action_consumed_amount_list' in d:
            o.biz_action_consumed_amount_list = d['biz_action_consumed_amount_list']
        if 'biz_uk_id' in d:
            o.biz_uk_id = d['biz_uk_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SalesData(object):

    def __init__(self):
        self._dt = None
        self._order_count = None
        self._refund_order_count = None
        self._refund_sales_amount = None
        self._sales_amount = None

    @property
    def dt(self):
        return self._dt

    @dt.setter
    def dt(self, value):
        self._dt = value
    @property
    def order_count(self):
        return self._order_count

    @order_count.setter
    def order_count(self, value):
        self._order_count = value
    @property
    def refund_order_count(self):
        return self._refund_order_count

    @refund_order_count.setter
    def refund_order_count(self, value):
        self._refund_order_count = value
    @property
    def refund_sales_amount(self):
        return self._refund_sales_amount

    @refund_sales_amount.setter
    def refund_sales_amount(self, value):
        self._refund_sales_amount = value
    @property
    def sales_amount(self):
        return self._sales_amount

    @sales_amount.setter
    def sales_amount(self, value):
        self._sales_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.dt:
            if hasattr(self.dt, 'to_alipay_dict'):
                params['dt'] = self.dt.to_alipay_dict()
            else:
                params['dt'] = self.dt
        if self.order_count:
            if hasattr(self.order_count, 'to_alipay_dict'):
                params['order_count'] = self.order_count.to_alipay_dict()
            else:
                params['order_count'] = self.order_count
        if self.refund_order_count:
            if hasattr(self.refund_order_count, 'to_alipay_dict'):
                params['refund_order_count'] = self.refund_order_count.to_alipay_dict()
            else:
                params['refund_order_count'] = self.refund_order_count
        if self.refund_sales_amount:
            if hasattr(self.refund_sales_amount, 'to_alipay_dict'):
                params['refund_sales_amount'] = self.refund_sales_amount.to_alipay_dict()
            else:
                params['refund_sales_amount'] = self.refund_sales_amount
        if self.sales_amount:
            if hasattr(self.sales_amount, 'to_alipay_dict'):
                params['sales_amount'] = self.sales_amount.to_alipay_dict()
            else:
                params['sales_amount'] = self.sales_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SalesData()
        if 'dt' in d:
            o.dt = d['dt']
        if 'order_count' in d:
            o.order_count = d['order_count']
        if 'refund_order_count' in d:
            o.refund_order_count = d['refund_order_count']
        if 'refund_sales_amount' in d:
            o.refund_sales_amount = d['refund_sales_amount']
        if 'sales_amount' in d:
            o.sales_amount = d['sales_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class InvoiceRevAmountDTO(object):

    def __init__(self):
        self._bill_no = None
        self._no_vat_receiveable_amount = None
        self._no_vat_tax_loss_amount = None
        self._no_vat_tax_loss_rate = None
        self._out_bill_no = None
        self._receiveable_amount = None
        self._vat_nomal_receiveable_amount = None
        self._vat_nomal_tax_loss_amount = None
        self._vat_nomal_tax_loss_rate = None
        self._vat_special_receiveable_amount = None

    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def no_vat_receiveable_amount(self):
        return self._no_vat_receiveable_amount

    @no_vat_receiveable_amount.setter
    def no_vat_receiveable_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._no_vat_receiveable_amount = value
        else:
            self._no_vat_receiveable_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def no_vat_tax_loss_amount(self):
        return self._no_vat_tax_loss_amount

    @no_vat_tax_loss_amount.setter
    def no_vat_tax_loss_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._no_vat_tax_loss_amount = value
        else:
            self._no_vat_tax_loss_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def no_vat_tax_loss_rate(self):
        return self._no_vat_tax_loss_rate

    @no_vat_tax_loss_rate.setter
    def no_vat_tax_loss_rate(self, value):
        self._no_vat_tax_loss_rate = value
    @property
    def out_bill_no(self):
        return self._out_bill_no

    @out_bill_no.setter
    def out_bill_no(self, value):
        self._out_bill_no = value
    @property
    def receiveable_amount(self):
        return self._receiveable_amount

    @receiveable_amount.setter
    def receiveable_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._receiveable_amount = value
        else:
            self._receiveable_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def vat_nomal_receiveable_amount(self):
        return self._vat_nomal_receiveable_amount

    @vat_nomal_receiveable_amount.setter
    def vat_nomal_receiveable_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._vat_nomal_receiveable_amount = value
        else:
            self._vat_nomal_receiveable_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def vat_nomal_tax_loss_amount(self):
        return self._vat_nomal_tax_loss_amount

    @vat_nomal_tax_loss_amount.setter
    def vat_nomal_tax_loss_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._vat_nomal_tax_loss_amount = value
        else:
            self._vat_nomal_tax_loss_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def vat_nomal_tax_loss_rate(self):
        return self._vat_nomal_tax_loss_rate

    @vat_nomal_tax_loss_rate.setter
    def vat_nomal_tax_loss_rate(self, value):
        self._vat_nomal_tax_loss_rate = value
    @property
    def vat_special_receiveable_amount(self):
        return self._vat_special_receiveable_amount

    @vat_special_receiveable_amount.setter
    def vat_special_receiveable_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._vat_special_receiveable_amount = value
        else:
            self._vat_special_receiveable_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.no_vat_receiveable_amount:
            if hasattr(self.no_vat_receiveable_amount, 'to_alipay_dict'):
                params['no_vat_receiveable_amount'] = self.no_vat_receiveable_amount.to_alipay_dict()
            else:
                params['no_vat_receiveable_amount'] = self.no_vat_receiveable_amount
        if self.no_vat_tax_loss_amount:
            if hasattr(self.no_vat_tax_loss_amount, 'to_alipay_dict'):
                params['no_vat_tax_loss_amount'] = self.no_vat_tax_loss_amount.to_alipay_dict()
            else:
                params['no_vat_tax_loss_amount'] = self.no_vat_tax_loss_amount
        if self.no_vat_tax_loss_rate:
            if hasattr(self.no_vat_tax_loss_rate, 'to_alipay_dict'):
                params['no_vat_tax_loss_rate'] = self.no_vat_tax_loss_rate.to_alipay_dict()
            else:
                params['no_vat_tax_loss_rate'] = self.no_vat_tax_loss_rate
        if self.out_bill_no:
            if hasattr(self.out_bill_no, 'to_alipay_dict'):
                params['out_bill_no'] = self.out_bill_no.to_alipay_dict()
            else:
                params['out_bill_no'] = self.out_bill_no
        if self.receiveable_amount:
            if hasattr(self.receiveable_amount, 'to_alipay_dict'):
                params['receiveable_amount'] = self.receiveable_amount.to_alipay_dict()
            else:
                params['receiveable_amount'] = self.receiveable_amount
        if self.vat_nomal_receiveable_amount:
            if hasattr(self.vat_nomal_receiveable_amount, 'to_alipay_dict'):
                params['vat_nomal_receiveable_amount'] = self.vat_nomal_receiveable_amount.to_alipay_dict()
            else:
                params['vat_nomal_receiveable_amount'] = self.vat_nomal_receiveable_amount
        if self.vat_nomal_tax_loss_amount:
            if hasattr(self.vat_nomal_tax_loss_amount, 'to_alipay_dict'):
                params['vat_nomal_tax_loss_amount'] = self.vat_nomal_tax_loss_amount.to_alipay_dict()
            else:
                params['vat_nomal_tax_loss_amount'] = self.vat_nomal_tax_loss_amount
        if self.vat_nomal_tax_loss_rate:
            if hasattr(self.vat_nomal_tax_loss_rate, 'to_alipay_dict'):
                params['vat_nomal_tax_loss_rate'] = self.vat_nomal_tax_loss_rate.to_alipay_dict()
            else:
                params['vat_nomal_tax_loss_rate'] = self.vat_nomal_tax_loss_rate
        if self.vat_special_receiveable_amount:
            if hasattr(self.vat_special_receiveable_amount, 'to_alipay_dict'):
                params['vat_special_receiveable_amount'] = self.vat_special_receiveable_amount.to_alipay_dict()
            else:
                params['vat_special_receiveable_amount'] = self.vat_special_receiveable_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InvoiceRevAmountDTO()
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'no_vat_receiveable_amount' in d:
            o.no_vat_receiveable_amount = d['no_vat_receiveable_amount']
        if 'no_vat_tax_loss_amount' in d:
            o.no_vat_tax_loss_amount = d['no_vat_tax_loss_amount']
        if 'no_vat_tax_loss_rate' in d:
            o.no_vat_tax_loss_rate = d['no_vat_tax_loss_rate']
        if 'out_bill_no' in d:
            o.out_bill_no = d['out_bill_no']
        if 'receiveable_amount' in d:
            o.receiveable_amount = d['receiveable_amount']
        if 'vat_nomal_receiveable_amount' in d:
            o.vat_nomal_receiveable_amount = d['vat_nomal_receiveable_amount']
        if 'vat_nomal_tax_loss_amount' in d:
            o.vat_nomal_tax_loss_amount = d['vat_nomal_tax_loss_amount']
        if 'vat_nomal_tax_loss_rate' in d:
            o.vat_nomal_tax_loss_rate = d['vat_nomal_tax_loss_rate']
        if 'vat_special_receiveable_amount' in d:
            o.vat_special_receiveable_amount = d['vat_special_receiveable_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingActivitySettleQueryModel(object):

    def __init__(self):
        self._activity_id = None
        self._order_no = None
        self._settle_no = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def settle_no(self):
        return self._settle_no

    @settle_no.setter
    def settle_no(self, value):
        self._settle_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.settle_no:
            if hasattr(self.settle_no, 'to_alipay_dict'):
                params['settle_no'] = self.settle_no.to_alipay_dict()
            else:
                params['settle_no'] = self.settle_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivitySettleQueryModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'settle_no' in d:
            o.settle_no = d['settle_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundAllocTransferQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundAllocTransferQueryResponse, self).__init__()
        self._alloc_time = None
        self._amount = None
        self._biz_type = None
        self._certification_no = None
        self._certification_type = None
        self._order_id = None
        self._out_biz_no = None
        self._status = None

    @property
    def alloc_time(self):
        return self._alloc_time

    @alloc_time.setter
    def alloc_time(self, value):
        self._alloc_time = value
    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def certification_no(self):
        return self._certification_no

    @certification_no.setter
    def certification_no(self, value):
        self._certification_no = value
    @property
    def certification_type(self):
        return self._certification_type

    @certification_type.setter
    def certification_type(self, value):
        self._certification_type = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundAllocTransferQueryResponse, self).parse_response_content(response_content)
        if 'alloc_time' in response:
            self.alloc_time = response['alloc_time']
        if 'amount' in response:
            self.amount = response['amount']
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'certification_no' in response:
            self.certification_no = response['certification_no']
        if 'certification_type' in response:
            self.certification_type = response['certification_type']
        if 'order_id' in response:
            self.order_id = response['order_id']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaMerchantSingleDataUploadModel(object):

    def __init__(self):
        self._biz_ext_params = None
        self._data = None
        self._linked_merchant_id = None
        self._primary_keys = None
        self._scene_code = None

    @property
    def biz_ext_params(self):
        return self._biz_ext_params

    @biz_ext_params.setter
    def biz_ext_params(self, value):
        self._biz_ext_params = value
    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def linked_merchant_id(self):
        return self._linked_merchant_id

    @linked_merchant_id.setter
    def linked_merchant_id(self, value):
        self._linked_merchant_id = value
    @property
    def primary_keys(self):
        return self._primary_keys

    @primary_keys.setter
    def primary_keys(self, value):
        self._primary_keys = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_ext_params:
            if hasattr(self.biz_ext_params, 'to_alipay_dict'):
                params['biz_ext_params'] = self.biz_ext_params.to_alipay_dict()
            else:
                params['biz_ext_params'] = self.biz_ext_params
        if self.data:
            if hasattr(self.data, 'to_alipay_dict'):
                params['data'] = self.data.to_alipay_dict()
            else:
                params['data'] = self.data
        if self.linked_merchant_id:
            if hasattr(self.linked_merchant_id, 'to_alipay_dict'):
                params['linked_merchant_id'] = self.linked_merchant_id.to_alipay_dict()
            else:
                params['linked_merchant_id'] = self.linked_merchant_id
        if self.primary_keys:
            if hasattr(self.primary_keys, 'to_alipay_dict'):
                params['primary_keys'] = self.primary_keys.to_alipay_dict()
            else:
                params['primary_keys'] = self.primary_keys
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaMerchantSingleDataUploadModel()
        if 'biz_ext_params' in d:
            o.biz_ext_params = d['biz_ext_params']
        if 'data' in d:
            o.data = d['data']
        if 'linked_merchant_id' in d:
            o.linked_merchant_id = d['linked_merchant_id']
        if 'primary_keys' in d:
            o.primary_keys = d['primary_keys']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class HbMerchantShopDetailInfo(object):

    def __init__(self):
        self._address = None
        self._distance = None
        self._shop_id = None
        self._shop_name = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def distance(self):
        return self._distance

    @distance.setter
    def distance(self, value):
        self._distance = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.distance:
            if hasattr(self.distance, 'to_alipay_dict'):
                params['distance'] = self.distance.to_alipay_dict()
            else:
                params['distance'] = self.distance
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = HbMerchantShopDetailInfo()
        if 'address' in d:
            o.address = d['address']
        if 'distance' in d:
            o.distance = d['distance']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BaseWebResponse(object):

    def __init__(self):
        self._code = None
        self._message = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, value):
        self._message = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.message:
            if hasattr(self.message, 'to_alipay_dict'):
                params['message'] = self.message.to_alipay_dict()
            else:
                params['message'] = self.message
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BaseWebResponse()
        if 'code' in d:
            o.code = d['code']
        if 'message' in d:
            o.message = d['message']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceExpenserulesGroupemployeeModifyModel(object):

    def __init__(self):
        self._account_id = None
        self._add_employee_list = None
        self._add_employee_open_id_list = None
        self._agreement_no = None
        self._enterprise_id = None
        self._group_id_list = None
        self._remove_employee_list = None
        self._remove_employee_open_id_list = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def add_employee_list(self):
        return self._add_employee_list

    @add_employee_list.setter
    def add_employee_list(self, value):
        if isinstance(value, list):
            self._add_employee_list = list()
            for i in value:
                self._add_employee_list.append(i)
    @property
    def add_employee_open_id_list(self):
        return self._add_employee_open_id_list

    @add_employee_open_id_list.setter
    def add_employee_open_id_list(self, value):
        if isinstance(value, list):
            self._add_employee_open_id_list = list()
            for i in value:
                self._add_employee_open_id_list.append(i)
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def group_id_list(self):
        return self._group_id_list

    @group_id_list.setter
    def group_id_list(self, value):
        if isinstance(value, list):
            self._group_id_list = list()
            for i in value:
                self._group_id_list.append(i)
    @property
    def remove_employee_list(self):
        return self._remove_employee_list

    @remove_employee_list.setter
    def remove_employee_list(self, value):
        if isinstance(value, list):
            self._remove_employee_list = list()
            for i in value:
                self._remove_employee_list.append(i)
    @property
    def remove_employee_open_id_list(self):
        return self._remove_employee_open_id_list

    @remove_employee_open_id_list.setter
    def remove_employee_open_id_list(self, value):
        if isinstance(value, list):
            self._remove_employee_open_id_list = list()
            for i in value:
                self._remove_employee_open_id_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.add_employee_list:
            if isinstance(self.add_employee_list, list):
                for i in range(0, len(self.add_employee_list)):
                    element = self.add_employee_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.add_employee_list[i] = element.to_alipay_dict()
            if hasattr(self.add_employee_list, 'to_alipay_dict'):
                params['add_employee_list'] = self.add_employee_list.to_alipay_dict()
            else:
                params['add_employee_list'] = self.add_employee_list
        if self.add_employee_open_id_list:
            if isinstance(self.add_employee_open_id_list, list):
                for i in range(0, len(self.add_employee_open_id_list)):
                    element = self.add_employee_open_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.add_employee_open_id_list[i] = element.to_alipay_dict()
            if hasattr(self.add_employee_open_id_list, 'to_alipay_dict'):
                params['add_employee_open_id_list'] = self.add_employee_open_id_list.to_alipay_dict()
            else:
                params['add_employee_open_id_list'] = self.add_employee_open_id_list
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.group_id_list:
            if isinstance(self.group_id_list, list):
                for i in range(0, len(self.group_id_list)):
                    element = self.group_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.group_id_list[i] = element.to_alipay_dict()
            if hasattr(self.group_id_list, 'to_alipay_dict'):
                params['group_id_list'] = self.group_id_list.to_alipay_dict()
            else:
                params['group_id_list'] = self.group_id_list
        if self.remove_employee_list:
            if isinstance(self.remove_employee_list, list):
                for i in range(0, len(self.remove_employee_list)):
                    element = self.remove_employee_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.remove_employee_list[i] = element.to_alipay_dict()
            if hasattr(self.remove_employee_list, 'to_alipay_dict'):
                params['remove_employee_list'] = self.remove_employee_list.to_alipay_dict()
            else:
                params['remove_employee_list'] = self.remove_employee_list
        if self.remove_employee_open_id_list:
            if isinstance(self.remove_employee_open_id_list, list):
                for i in range(0, len(self.remove_employee_open_id_list)):
                    element = self.remove_employee_open_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.remove_employee_open_id_list[i] = element.to_alipay_dict()
            if hasattr(self.remove_employee_open_id_list, 'to_alipay_dict'):
                params['remove_employee_open_id_list'] = self.remove_employee_open_id_list.to_alipay_dict()
            else:
                params['remove_employee_open_id_list'] = self.remove_employee_open_id_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceExpenserulesGroupemployeeModifyModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'add_employee_list' in d:
            o.add_employee_list = d['add_employee_list']
        if 'add_employee_open_id_list' in d:
            o.add_employee_open_id_list = d['add_employee_open_id_list']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'group_id_list' in d:
            o.group_id_list = d['group_id_list']
        if 'remove_employee_list' in d:
            o.remove_employee_list = d['remove_employee_list']
        if 'remove_employee_open_id_list' in d:
            o.remove_employee_open_id_list = d['remove_employee_open_id_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataAiserviceCloudbusMetroodQueryModel(object):

    def __init__(self):
        self._app_version = None
        self._city_code = None
        self._end_date = None
        self._is_out = None
        self._partner_id = None
        self._start_date = None
        self._station_id = None
        self._type = None

    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def is_out(self):
        return self._is_out

    @is_out.setter
    def is_out(self, value):
        self._is_out = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def station_id(self):
        return self._station_id

    @station_id.setter
    def station_id(self, value):
        self._station_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.is_out:
            if hasattr(self.is_out, 'to_alipay_dict'):
                params['is_out'] = self.is_out.to_alipay_dict()
            else:
                params['is_out'] = self.is_out
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.station_id:
            if hasattr(self.station_id, 'to_alipay_dict'):
                params['station_id'] = self.station_id.to_alipay_dict()
            else:
                params['station_id'] = self.station_id
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataAiserviceCloudbusMetroodQueryModel()
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'is_out' in d:
            o.is_out = d['is_out']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'station_id' in d:
            o.station_id = d['station_id']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenBatchExpireVoucher(object):

    def __init__(self):
        self._available_aount = None
        self._available_count = None
        self._expire_amount = None
        self._voucher_id = None

    @property
    def available_aount(self):
        return self._available_aount

    @available_aount.setter
    def available_aount(self, value):
        self._available_aount = value
    @property
    def available_count(self):
        return self._available_count

    @available_count.setter
    def available_count(self, value):
        self._available_count = value
    @property
    def expire_amount(self):
        return self._expire_amount

    @expire_amount.setter
    def expire_amount(self, value):
        self._expire_amount = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.available_aount:
            if hasattr(self.available_aount, 'to_alipay_dict'):
                params['available_aount'] = self.available_aount.to_alipay_dict()
            else:
                params['available_aount'] = self.available_aount
        if self.available_count:
            if hasattr(self.available_count, 'to_alipay_dict'):
                params['available_count'] = self.available_count.to_alipay_dict()
            else:
                params['available_count'] = self.available_count
        if self.expire_amount:
            if hasattr(self.expire_amount, 'to_alipay_dict'):
                params['expire_amount'] = self.expire_amount.to_alipay_dict()
            else:
                params['expire_amount'] = self.expire_amount
        if self.voucher_id:
            if hasattr(self.voucher_id, 'to_alipay_dict'):
                params['voucher_id'] = self.voucher_id.to_alipay_dict()
            else:
                params['voucher_id'] = self.voucher_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenBatchExpireVoucher()
        if 'available_aount' in d:
            o.available_aount = d['available_aount']
        if 'available_count' in d:
            o.available_count = d['available_count']
        if 'expire_amount' in d:
            o.expire_amount = d['expire_amount']
        if 'voucher_id' in d:
            o.voucher_id = d['voucher_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherMiniAppUseGuideInfo import VoucherMiniAppUseGuideInfo


class VoucherUseGuideInfo(object):

    def __init__(self):
        self._mini_app_use_guide_info = None
        self._use_guide_mode = None

    @property
    def mini_app_use_guide_info(self):
        return self._mini_app_use_guide_info

    @mini_app_use_guide_info.setter
    def mini_app_use_guide_info(self, value):
        if isinstance(value, VoucherMiniAppUseGuideInfo):
            self._mini_app_use_guide_info = value
        else:
            self._mini_app_use_guide_info = VoucherMiniAppUseGuideInfo.from_alipay_dict(value)
    @property
    def use_guide_mode(self):
        return self._use_guide_mode

    @use_guide_mode.setter
    def use_guide_mode(self, value):
        if isinstance(value, list):
            self._use_guide_mode = list()
            for i in value:
                self._use_guide_mode.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.mini_app_use_guide_info:
            if hasattr(self.mini_app_use_guide_info, 'to_alipay_dict'):
                params['mini_app_use_guide_info'] = self.mini_app_use_guide_info.to_alipay_dict()
            else:
                params['mini_app_use_guide_info'] = self.mini_app_use_guide_info
        if self.use_guide_mode:
            if isinstance(self.use_guide_mode, list):
                for i in range(0, len(self.use_guide_mode)):
                    element = self.use_guide_mode[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.use_guide_mode[i] = element.to_alipay_dict()
            if hasattr(self.use_guide_mode, 'to_alipay_dict'):
                params['use_guide_mode'] = self.use_guide_mode.to_alipay_dict()
            else:
                params['use_guide_mode'] = self.use_guide_mode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherUseGuideInfo()
        if 'mini_app_use_guide_info' in d:
            o.mini_app_use_guide_info = d['mini_app_use_guide_info']
        if 'use_guide_mode' in d:
            o.use_guide_mode = d['use_guide_mode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiTradeItemorderQueryModel(object):

    def __init__(self):
        self._order_no = None

    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiTradeItemorderQueryModel()
        if 'order_no' in d:
            o.order_no = d['order_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IotIdentityOrgQueryAllApiResponse import IotIdentityOrgQueryAllApiResponse


class IotIdentityOrgQueryAllListApiResponse(object):

    def __init__(self):
        self._orgs = None

    @property
    def orgs(self):
        return self._orgs

    @orgs.setter
    def orgs(self, value):
        if isinstance(value, list):
            self._orgs = list()
            for i in value:
                if isinstance(i, IotIdentityOrgQueryAllApiResponse):
                    self._orgs.append(i)
                else:
                    self._orgs.append(IotIdentityOrgQueryAllApiResponse.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.orgs:
            if isinstance(self.orgs, list):
                for i in range(0, len(self.orgs)):
                    element = self.orgs[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.orgs[i] = element.to_alipay_dict()
            if hasattr(self.orgs, 'to_alipay_dict'):
                params['orgs'] = self.orgs.to_alipay_dict()
            else:
                params['orgs'] = self.orgs
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IotIdentityOrgQueryAllListApiResponse()
        if 'orgs' in d:
            o.orgs = d['orgs']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MsgContent import MsgContent
from alipay.aop.api.domain.MsgDynamicData import MsgDynamicData


class AlipayEcoMycarSystemTemplatemessageSendModel(object):

    def __init__(self):
        self._msg_content = None
        self._msg_dynamic_datas = None
        self._msg_id = None
        self._msg_subject_id = None
        self._msg_type = None
        self._open_id = None
        self._params = None
        self._user_id = None

    @property
    def msg_content(self):
        return self._msg_content

    @msg_content.setter
    def msg_content(self, value):
        if isinstance(value, MsgContent):
            self._msg_content = value
        else:
            self._msg_content = MsgContent.from_alipay_dict(value)
    @property
    def msg_dynamic_datas(self):
        return self._msg_dynamic_datas

    @msg_dynamic_datas.setter
    def msg_dynamic_datas(self, value):
        if isinstance(value, list):
            self._msg_dynamic_datas = list()
            for i in value:
                if isinstance(i, MsgDynamicData):
                    self._msg_dynamic_datas.append(i)
                else:
                    self._msg_dynamic_datas.append(MsgDynamicData.from_alipay_dict(i))
    @property
    def msg_id(self):
        return self._msg_id

    @msg_id.setter
    def msg_id(self, value):
        self._msg_id = value
    @property
    def msg_subject_id(self):
        return self._msg_subject_id

    @msg_subject_id.setter
    def msg_subject_id(self, value):
        self._msg_subject_id = value
    @property
    def msg_type(self):
        return self._msg_type

    @msg_type.setter
    def msg_type(self, value):
        self._msg_type = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def params(self):
        return self._params

    @params.setter
    def params(self, value):
        self._params = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.msg_content:
            if hasattr(self.msg_content, 'to_alipay_dict'):
                params['msg_content'] = self.msg_content.to_alipay_dict()
            else:
                params['msg_content'] = self.msg_content
        if self.msg_dynamic_datas:
            if isinstance(self.msg_dynamic_datas, list):
                for i in range(0, len(self.msg_dynamic_datas)):
                    element = self.msg_dynamic_datas[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.msg_dynamic_datas[i] = element.to_alipay_dict()
            if hasattr(self.msg_dynamic_datas, 'to_alipay_dict'):
                params['msg_dynamic_datas'] = self.msg_dynamic_datas.to_alipay_dict()
            else:
                params['msg_dynamic_datas'] = self.msg_dynamic_datas
        if self.msg_id:
            if hasattr(self.msg_id, 'to_alipay_dict'):
                params['msg_id'] = self.msg_id.to_alipay_dict()
            else:
                params['msg_id'] = self.msg_id
        if self.msg_subject_id:
            if hasattr(self.msg_subject_id, 'to_alipay_dict'):
                params['msg_subject_id'] = self.msg_subject_id.to_alipay_dict()
            else:
                params['msg_subject_id'] = self.msg_subject_id
        if self.msg_type:
            if hasattr(self.msg_type, 'to_alipay_dict'):
                params['msg_type'] = self.msg_type.to_alipay_dict()
            else:
                params['msg_type'] = self.msg_type
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.params:
            if hasattr(self.params, 'to_alipay_dict'):
                params['params'] = self.params.to_alipay_dict()
            else:
                params['params'] = self.params
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarSystemTemplatemessageSendModel()
        if 'msg_content' in d:
            o.msg_content = d['msg_content']
        if 'msg_dynamic_datas' in d:
            o.msg_dynamic_datas = d['msg_dynamic_datas']
        if 'msg_id' in d:
            o.msg_id = d['msg_id']
        if 'msg_subject_id' in d:
            o.msg_subject_id = d['msg_subject_id']
        if 'msg_type' in d:
            o.msg_type = d['msg_type']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'params' in d:
            o.params = d['params']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenOpenbizmocktoolsQueryModel(object):

    def __init__(self):
        self._app_number = None
        self._biz_id = None
        self._biz_type = None
        self._condition = None
        self._env = None
        self._group_id = None
        self._interface_name = None
        self._oid = None
        self._operation_type = None
        self._pid = None
        self._service = None

    @property
    def app_number(self):
        return self._app_number

    @app_number.setter
    def app_number(self, value):
        self._app_number = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def condition(self):
        return self._condition

    @condition.setter
    def condition(self, value):
        self._condition = value
    @property
    def env(self):
        return self._env

    @env.setter
    def env(self, value):
        self._env = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def interface_name(self):
        return self._interface_name

    @interface_name.setter
    def interface_name(self, value):
        self._interface_name = value
    @property
    def oid(self):
        return self._oid

    @oid.setter
    def oid(self, value):
        self._oid = value
    @property
    def operation_type(self):
        return self._operation_type

    @operation_type.setter
    def operation_type(self, value):
        self._operation_type = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def service(self):
        return self._service

    @service.setter
    def service(self, value):
        self._service = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_number:
            if hasattr(self.app_number, 'to_alipay_dict'):
                params['app_number'] = self.app_number.to_alipay_dict()
            else:
                params['app_number'] = self.app_number
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.condition:
            if hasattr(self.condition, 'to_alipay_dict'):
                params['condition'] = self.condition.to_alipay_dict()
            else:
                params['condition'] = self.condition
        if self.env:
            if hasattr(self.env, 'to_alipay_dict'):
                params['env'] = self.env.to_alipay_dict()
            else:
                params['env'] = self.env
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.interface_name:
            if hasattr(self.interface_name, 'to_alipay_dict'):
                params['interface_name'] = self.interface_name.to_alipay_dict()
            else:
                params['interface_name'] = self.interface_name
        if self.oid:
            if hasattr(self.oid, 'to_alipay_dict'):
                params['oid'] = self.oid.to_alipay_dict()
            else:
                params['oid'] = self.oid
        if self.operation_type:
            if hasattr(self.operation_type, 'to_alipay_dict'):
                params['operation_type'] = self.operation_type.to_alipay_dict()
            else:
                params['operation_type'] = self.operation_type
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.service:
            if hasattr(self.service, 'to_alipay_dict'):
                params['service'] = self.service.to_alipay_dict()
            else:
                params['service'] = self.service
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenOpenbizmocktoolsQueryModel()
        if 'app_number' in d:
            o.app_number = d['app_number']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'condition' in d:
            o.condition = d['condition']
        if 'env' in d:
            o.env = d['env']
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'interface_name' in d:
            o.interface_name = d['interface_name']
        if 'oid' in d:
            o.oid = d['oid']
        if 'operation_type' in d:
            o.operation_type = d['operation_type']
        if 'pid' in d:
            o.pid = d['pid']
        if 'service' in d:
            o.service = d['service']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppIndustryNucleicremindSubscribeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppIndustryNucleicremindSubscribeQueryResponse, self).__init__()
        self._effective_hour = None
        self._reminder_hour_list = None
        self._result_time = None
        self._status = None

    @property
    def effective_hour(self):
        return self._effective_hour

    @effective_hour.setter
    def effective_hour(self, value):
        self._effective_hour = value
    @property
    def reminder_hour_list(self):
        return self._reminder_hour_list

    @reminder_hour_list.setter
    def reminder_hour_list(self, value):
        if isinstance(value, list):
            self._reminder_hour_list = list()
            for i in value:
                self._reminder_hour_list.append(i)
    @property
    def result_time(self):
        return self._result_time

    @result_time.setter
    def result_time(self, value):
        self._result_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppIndustryNucleicremindSubscribeQueryResponse, self).parse_response_content(response_content)
        if 'effective_hour' in response:
            self.effective_hour = response['effective_hour']
        if 'reminder_hour_list' in response:
            self.reminder_hour_list = response['reminder_hour_list']
        if 'result_time' in response:
            self.result_time = response['result_time']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbdishCookCateTopInfo(object):

    def __init__(self):
        self._catetory_id = None
        self._cook_id = None
        self._create_user = None
        self._oper_type = None
        self._update_user = None

    @property
    def catetory_id(self):
        return self._catetory_id

    @catetory_id.setter
    def catetory_id(self, value):
        self._catetory_id = value
    @property
    def cook_id(self):
        return self._cook_id

    @cook_id.setter
    def cook_id(self, value):
        self._cook_id = value
    @property
    def create_user(self):
        return self._create_user

    @create_user.setter
    def create_user(self, value):
        self._create_user = value
    @property
    def oper_type(self):
        return self._oper_type

    @oper_type.setter
    def oper_type(self, value):
        self._oper_type = value
    @property
    def update_user(self):
        return self._update_user

    @update_user.setter
    def update_user(self, value):
        self._update_user = value


    def to_alipay_dict(self):
        params = dict()
        if self.catetory_id:
            if hasattr(self.catetory_id, 'to_alipay_dict'):
                params['catetory_id'] = self.catetory_id.to_alipay_dict()
            else:
                params['catetory_id'] = self.catetory_id
        if self.cook_id:
            if hasattr(self.cook_id, 'to_alipay_dict'):
                params['cook_id'] = self.cook_id.to_alipay_dict()
            else:
                params['cook_id'] = self.cook_id
        if self.create_user:
            if hasattr(self.create_user, 'to_alipay_dict'):
                params['create_user'] = self.create_user.to_alipay_dict()
            else:
                params['create_user'] = self.create_user
        if self.oper_type:
            if hasattr(self.oper_type, 'to_alipay_dict'):
                params['oper_type'] = self.oper_type.to_alipay_dict()
            else:
                params['oper_type'] = self.oper_type
        if self.update_user:
            if hasattr(self.update_user, 'to_alipay_dict'):
                params['update_user'] = self.update_user.to_alipay_dict()
            else:
                params['update_user'] = self.update_user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbdishCookCateTopInfo()
        if 'catetory_id' in d:
            o.catetory_id = d['catetory_id']
        if 'cook_id' in d:
            o.cook_id = d['cook_id']
        if 'create_user' in d:
            o.create_user = d['create_user']
        if 'oper_type' in d:
            o.oper_type = d['oper_type']
        if 'update_user' in d:
            o.update_user = d['update_user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class LotteryType(object):

    def __init__(self):
        self._lottery_type_id = None
        self._lottery_type_name = None

    @property
    def lottery_type_id(self):
        return self._lottery_type_id

    @lottery_type_id.setter
    def lottery_type_id(self, value):
        self._lottery_type_id = value
    @property
    def lottery_type_name(self):
        return self._lottery_type_name

    @lottery_type_name.setter
    def lottery_type_name(self, value):
        self._lottery_type_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.lottery_type_id:
            if hasattr(self.lottery_type_id, 'to_alipay_dict'):
                params['lottery_type_id'] = self.lottery_type_id.to_alipay_dict()
            else:
                params['lottery_type_id'] = self.lottery_type_id
        if self.lottery_type_name:
            if hasattr(self.lottery_type_name, 'to_alipay_dict'):
                params['lottery_type_name'] = self.lottery_type_name.to_alipay_dict()
            else:
                params['lottery_type_name'] = self.lottery_type_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LotteryType()
        if 'lottery_type_id' in d:
            o.lottery_type_id = d['lottery_type_id']
        if 'lottery_type_name' in d:
            o.lottery_type_name = d['lottery_type_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ActivityAuditDTO import ActivityAuditDTO


class ActivityOrderDTO(object):

    def __init__(self):
        self._activity_audit_list = None
        self._audit_status = None
        self._order_id = None
        self._order_status = None
        self._order_type = None

    @property
    def activity_audit_list(self):
        return self._activity_audit_list

    @activity_audit_list.setter
    def activity_audit_list(self, value):
        if isinstance(value, list):
            self._activity_audit_list = list()
            for i in value:
                if isinstance(i, ActivityAuditDTO):
                    self._activity_audit_list.append(i)
                else:
                    self._activity_audit_list.append(ActivityAuditDTO.from_alipay_dict(i))
    @property
    def audit_status(self):
        return self._audit_status

    @audit_status.setter
    def audit_status(self, value):
        self._audit_status = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_audit_list:
            if isinstance(self.activity_audit_list, list):
                for i in range(0, len(self.activity_audit_list)):
                    element = self.activity_audit_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.activity_audit_list[i] = element.to_alipay_dict()
            if hasattr(self.activity_audit_list, 'to_alipay_dict'):
                params['activity_audit_list'] = self.activity_audit_list.to_alipay_dict()
            else:
                params['activity_audit_list'] = self.activity_audit_list
        if self.audit_status:
            if hasattr(self.audit_status, 'to_alipay_dict'):
                params['audit_status'] = self.audit_status.to_alipay_dict()
            else:
                params['audit_status'] = self.audit_status
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = self.order_type.to_alipay_dict()
            else:
                params['order_type'] = self.order_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityOrderDTO()
        if 'activity_audit_list' in d:
            o.activity_audit_list = d['activity_audit_list']
        if 'audit_status' in d:
            o.audit_status = d['audit_status']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'order_type' in d:
            o.order_type = d['order_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityDataAlibabaSecuritydataQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityDataAlibabaSecuritydataQueryResponse, self).__init__()
        self._content = None
        self._identify_result = None
        self._risk_label = None
        self._risk_score = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def identify_result(self):
        return self._identify_result

    @identify_result.setter
    def identify_result(self, value):
        self._identify_result = value
    @property
    def risk_label(self):
        return self._risk_label

    @risk_label.setter
    def risk_label(self, value):
        self._risk_label = value
    @property
    def risk_score(self):
        return self._risk_score

    @risk_score.setter
    def risk_score(self, value):
        self._risk_score = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityDataAlibabaSecuritydataQueryResponse, self).parse_response_content(response_content)
        if 'content' in response:
            self.content = response['content']
        if 'identify_result' in response:
            self.identify_result = response['identify_result']
        if 'risk_label' in response:
            self.risk_label = response['risk_label']
        if 'risk_score' in response:
            self.risk_score = response['risk_score']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsInsmopRetainQueryModel(object):

    def __init__(self):
        self._access_token = None
        self._ins_code = None

    @property
    def access_token(self):
        return self._access_token

    @access_token.setter
    def access_token(self, value):
        self._access_token = value
    @property
    def ins_code(self):
        return self._ins_code

    @ins_code.setter
    def ins_code(self, value):
        self._ins_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.access_token:
            if hasattr(self.access_token, 'to_alipay_dict'):
                params['access_token'] = self.access_token.to_alipay_dict()
            else:
                params['access_token'] = self.access_token
        if self.ins_code:
            if hasattr(self.ins_code, 'to_alipay_dict'):
                params['ins_code'] = self.ins_code.to_alipay_dict()
            else:
                params['ins_code'] = self.ins_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsInsmopRetainQueryModel()
        if 'access_token' in d:
            o.access_token = d['access_token']
        if 'ins_code' in d:
            o.ins_code = d['ins_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMerchantShopQueryModel(object):

    def __init__(self):
        self._auth_code = None
        self._dept_id = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def dept_id(self):
        return self._dept_id

    @dept_id.setter
    def dept_id(self, value):
        self._dept_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_code:
            if hasattr(self.auth_code, 'to_alipay_dict'):
                params['auth_code'] = self.auth_code.to_alipay_dict()
            else:
                params['auth_code'] = self.auth_code
        if self.dept_id:
            if hasattr(self.dept_id, 'to_alipay_dict'):
                params['dept_id'] = self.dept_id.to_alipay_dict()
            else:
                params['dept_id'] = self.dept_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMerchantShopQueryModel()
        if 'auth_code' in d:
            o.auth_code = d['auth_code']
        if 'dept_id' in d:
            o.dept_id = d['dept_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.HealthServiceFamilyDoctorDrugDTO import HealthServiceFamilyDoctorDrugDTO


class AlipayInsSceneFamilydoctorItemBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsSceneFamilydoctorItemBatchqueryResponse, self).__init__()
        self._drugs = None

    @property
    def drugs(self):
        return self._drugs

    @drugs.setter
    def drugs(self, value):
        if isinstance(value, list):
            self._drugs = list()
            for i in value:
                if isinstance(i, HealthServiceFamilyDoctorDrugDTO):
                    self._drugs.append(i)
                else:
                    self._drugs.append(HealthServiceFamilyDoctorDrugDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayInsSceneFamilydoctorItemBatchqueryResponse, self).parse_response_content(response_content)
        if 'drugs' in response:
            self.drugs = response['drugs']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Amount import Amount


class BenefitBudgetDTO(object):

    def __init__(self):
        self._amount = None
        self._budget_type = None
        self._count = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        if isinstance(value, Amount):
            self._amount = value
        else:
            self._amount = Amount.from_alipay_dict(value)
    @property
    def budget_type(self):
        return self._budget_type

    @budget_type.setter
    def budget_type(self, value):
        self._budget_type = value
    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.budget_type:
            if hasattr(self.budget_type, 'to_alipay_dict'):
                params['budget_type'] = self.budget_type.to_alipay_dict()
            else:
                params['budget_type'] = self.budget_type
        if self.count:
            if hasattr(self.count, 'to_alipay_dict'):
                params['count'] = self.count.to_alipay_dict()
            else:
                params['count'] = self.count
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BenefitBudgetDTO()
        if 'amount' in d:
            o.amount = d['amount']
        if 'budget_type' in d:
            o.budget_type = d['budget_type']
        if 'count' in d:
            o.count = d['count']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceExpensecontrolCostassertQueryModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._alipay_bill_no = None
        self._employee_id = None
        self._employee_open_id = None
        self._enterprise_id = None
        self._out_source_id = None
        self._platform = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def alipay_bill_no(self):
        return self._alipay_bill_no

    @alipay_bill_no.setter
    def alipay_bill_no(self, value):
        self._alipay_bill_no = value
    @property
    def employee_id(self):
        return self._employee_id

    @employee_id.setter
    def employee_id(self, value):
        self._employee_id = value
    @property
    def employee_open_id(self):
        return self._employee_open_id

    @employee_open_id.setter
    def employee_open_id(self, value):
        self._employee_open_id = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def out_source_id(self):
        return self._out_source_id

    @out_source_id.setter
    def out_source_id(self, value):
        self._out_source_id = value
    @property
    def platform(self):
        return self._platform

    @platform.setter
    def platform(self, value):
        self._platform = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.alipay_bill_no:
            if hasattr(self.alipay_bill_no, 'to_alipay_dict'):
                params['alipay_bill_no'] = self.alipay_bill_no.to_alipay_dict()
            else:
                params['alipay_bill_no'] = self.alipay_bill_no
        if self.employee_id:
            if hasattr(self.employee_id, 'to_alipay_dict'):
                params['employee_id'] = self.employee_id.to_alipay_dict()
            else:
                params['employee_id'] = self.employee_id
        if self.employee_open_id:
            if hasattr(self.employee_open_id, 'to_alipay_dict'):
                params['employee_open_id'] = self.employee_open_id.to_alipay_dict()
            else:
                params['employee_open_id'] = self.employee_open_id
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.out_source_id:
            if hasattr(self.out_source_id, 'to_alipay_dict'):
                params['out_source_id'] = self.out_source_id.to_alipay_dict()
            else:
                params['out_source_id'] = self.out_source_id
        if self.platform:
            if hasattr(self.platform, 'to_alipay_dict'):
                params['platform'] = self.platform.to_alipay_dict()
            else:
                params['platform'] = self.platform
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceExpensecontrolCostassertQueryModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'alipay_bill_no' in d:
            o.alipay_bill_no = d['alipay_bill_no']
        if 'employee_id' in d:
            o.employee_id = d['employee_id']
        if 'employee_open_id' in d:
            o.employee_open_id = d['employee_open_id']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'out_source_id' in d:
            o.out_source_id = d['out_source_id']
        if 'platform' in d:
            o.platform = d['platform']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CertifyConfig(object):

    def __init__(self):
        self._certify_biz_code = None
        self._need_address = None
        self._need_certify_id = None
        self._need_gender = None
        self._need_phone = None
        self._need_user_nation = None

    @property
    def certify_biz_code(self):
        return self._certify_biz_code

    @certify_biz_code.setter
    def certify_biz_code(self, value):
        self._certify_biz_code = value
    @property
    def need_address(self):
        return self._need_address

    @need_address.setter
    def need_address(self, value):
        self._need_address = value
    @property
    def need_certify_id(self):
        return self._need_certify_id

    @need_certify_id.setter
    def need_certify_id(self, value):
        self._need_certify_id = value
    @property
    def need_gender(self):
        return self._need_gender

    @need_gender.setter
    def need_gender(self, value):
        self._need_gender = value
    @property
    def need_phone(self):
        return self._need_phone

    @need_phone.setter
    def need_phone(self, value):
        self._need_phone = value
    @property
    def need_user_nation(self):
        return self._need_user_nation

    @need_user_nation.setter
    def need_user_nation(self, value):
        self._need_user_nation = value


    def to_alipay_dict(self):
        params = dict()
        if self.certify_biz_code:
            if hasattr(self.certify_biz_code, 'to_alipay_dict'):
                params['certify_biz_code'] = self.certify_biz_code.to_alipay_dict()
            else:
                params['certify_biz_code'] = self.certify_biz_code
        if self.need_address:
            if hasattr(self.need_address, 'to_alipay_dict'):
                params['need_address'] = self.need_address.to_alipay_dict()
            else:
                params['need_address'] = self.need_address
        if self.need_certify_id:
            if hasattr(self.need_certify_id, 'to_alipay_dict'):
                params['need_certify_id'] = self.need_certify_id.to_alipay_dict()
            else:
                params['need_certify_id'] = self.need_certify_id
        if self.need_gender:
            if hasattr(self.need_gender, 'to_alipay_dict'):
                params['need_gender'] = self.need_gender.to_alipay_dict()
            else:
                params['need_gender'] = self.need_gender
        if self.need_phone:
            if hasattr(self.need_phone, 'to_alipay_dict'):
                params['need_phone'] = self.need_phone.to_alipay_dict()
            else:
                params['need_phone'] = self.need_phone
        if self.need_user_nation:
            if hasattr(self.need_user_nation, 'to_alipay_dict'):
                params['need_user_nation'] = self.need_user_nation.to_alipay_dict()
            else:
                params['need_user_nation'] = self.need_user_nation
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CertifyConfig()
        if 'certify_biz_code' in d:
            o.certify_biz_code = d['certify_biz_code']
        if 'need_address' in d:
            o.need_address = d['need_address']
        if 'need_certify_id' in d:
            o.need_certify_id = d['need_certify_id']
        if 'need_gender' in d:
            o.need_gender = d['need_gender']
        if 'need_phone' in d:
            o.need_phone = d['need_phone']
        if 'need_user_nation' in d:
            o.need_user_nation = d['need_user_nation']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppRechargeNotifySendModel(object):

    def __init__(self):
        self._face_price = None
        self._gmt_charge = None
        self._mobile = None
        self._notify_type = None
        self._open_id = None
        self._out_user_id = None
        self._trade_no = None
        self._user_id = None

    @property
    def face_price(self):
        return self._face_price

    @face_price.setter
    def face_price(self, value):
        self._face_price = value
    @property
    def gmt_charge(self):
        return self._gmt_charge

    @gmt_charge.setter
    def gmt_charge(self, value):
        self._gmt_charge = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def notify_type(self):
        return self._notify_type

    @notify_type.setter
    def notify_type(self, value):
        self._notify_type = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_user_id(self):
        return self._out_user_id

    @out_user_id.setter
    def out_user_id(self, value):
        self._out_user_id = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.face_price:
            if hasattr(self.face_price, 'to_alipay_dict'):
                params['face_price'] = self.face_price.to_alipay_dict()
            else:
                params['face_price'] = self.face_price
        if self.gmt_charge:
            if hasattr(self.gmt_charge, 'to_alipay_dict'):
                params['gmt_charge'] = self.gmt_charge.to_alipay_dict()
            else:
                params['gmt_charge'] = self.gmt_charge
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.notify_type:
            if hasattr(self.notify_type, 'to_alipay_dict'):
                params['notify_type'] = self.notify_type.to_alipay_dict()
            else:
                params['notify_type'] = self.notify_type
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_user_id:
            if hasattr(self.out_user_id, 'to_alipay_dict'):
                params['out_user_id'] = self.out_user_id.to_alipay_dict()
            else:
                params['out_user_id'] = self.out_user_id
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppRechargeNotifySendModel()
        if 'face_price' in d:
            o.face_price = d['face_price']
        if 'gmt_charge' in d:
            o.gmt_charge = d['gmt_charge']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'notify_type' in d:
            o.notify_type = d['notify_type']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_user_id' in d:
            o.out_user_id = d['out_user_id']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OtherConfigVo(object):

    def __init__(self):
        self._biz_type = None
        self._charge_inst = None
        self._chargeoff_inst = None
        self._config_type = None
        self._content = None
        self._gmt_create = None
        self._gmt_modified = None
        self._id = None
        self._status = None
        self._sub_biz_type = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def chargeoff_inst(self):
        return self._chargeoff_inst

    @chargeoff_inst.setter
    def chargeoff_inst(self, value):
        self._chargeoff_inst = value
    @property
    def config_type(self):
        return self._config_type

    @config_type.setter
    def config_type(self, value):
        self._config_type = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.charge_inst:
            if hasattr(self.charge_inst, 'to_alipay_dict'):
                params['charge_inst'] = self.charge_inst.to_alipay_dict()
            else:
                params['charge_inst'] = self.charge_inst
        if self.chargeoff_inst:
            if hasattr(self.chargeoff_inst, 'to_alipay_dict'):
                params['chargeoff_inst'] = self.chargeoff_inst.to_alipay_dict()
            else:
                params['chargeoff_inst'] = self.chargeoff_inst
        if self.config_type:
            if hasattr(self.config_type, 'to_alipay_dict'):
                params['config_type'] = self.config_type.to_alipay_dict()
            else:
                params['config_type'] = self.config_type
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OtherConfigVo()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'charge_inst' in d:
            o.charge_inst = d['charge_inst']
        if 'chargeoff_inst' in d:
            o.chargeoff_inst = d['chargeoff_inst']
        if 'config_type' in d:
            o.config_type = d['config_type']
        if 'content' in d:
            o.content = d['content']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'id' in d:
            o.id = d['id']
        if 'status' in d:
            o.status = d['status']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MerchantInfoDTO(object):

    def __init__(self):
        self._brand_id = None
        self._mcc = None
        self._merchant_id = None

    @property
    def brand_id(self):
        return self._brand_id

    @brand_id.setter
    def brand_id(self, value):
        self._brand_id = value
    @property
    def mcc(self):
        return self._mcc

    @mcc.setter
    def mcc(self, value):
        self._mcc = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_id:
            if hasattr(self.brand_id, 'to_alipay_dict'):
                params['brand_id'] = self.brand_id.to_alipay_dict()
            else:
                params['brand_id'] = self.brand_id
        if self.mcc:
            if hasattr(self.mcc, 'to_alipay_dict'):
                params['mcc'] = self.mcc.to_alipay_dict()
            else:
                params['mcc'] = self.mcc
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MerchantInfoDTO()
        if 'brand_id' in d:
            o.brand_id = d['brand_id']
        if 'mcc' in d:
            o.mcc = d['mcc']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RefundChargeInfo import RefundChargeInfo
from alipay.aop.api.domain.TradeFundBill import TradeFundBill
from alipay.aop.api.domain.PresetPayToolInfo import PresetPayToolInfo


class AlipayTradeRefundResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeRefundResponse, self).__init__()
        self._buyer_logon_id = None
        self._buyer_open_id = None
        self._buyer_user_id = None
        self._fund_change = None
        self._gmt_refund_pay = None
        self._has_deposit_back = None
        self._open_id = None
        self._out_trade_no = None
        self._present_refund_buyer_amount = None
        self._present_refund_discount_amount = None
        self._present_refund_mdiscount_amount = None
        self._refund_charge_amount = None
        self._refund_charge_info_list = None
        self._refund_currency = None
        self._refund_detail_item_list = None
        self._refund_fee = None
        self._refund_hyb_amount = None
        self._refund_preset_paytool_list = None
        self._refund_settlement_id = None
        self._send_back_fee = None
        self._store_name = None
        self._trade_no = None

    @property
    def buyer_logon_id(self):
        return self._buyer_logon_id

    @buyer_logon_id.setter
    def buyer_logon_id(self, value):
        self._buyer_logon_id = value
    @property
    def buyer_open_id(self):
        return self._buyer_open_id

    @buyer_open_id.setter
    def buyer_open_id(self, value):
        self._buyer_open_id = value
    @property
    def buyer_user_id(self):
        return self._buyer_user_id

    @buyer_user_id.setter
    def buyer_user_id(self, value):
        self._buyer_user_id = value
    @property
    def fund_change(self):
        return self._fund_change

    @fund_change.setter
    def fund_change(self, value):
        self._fund_change = value
    @property
    def gmt_refund_pay(self):
        return self._gmt_refund_pay

    @gmt_refund_pay.setter
    def gmt_refund_pay(self, value):
        self._gmt_refund_pay = value
    @property
    def has_deposit_back(self):
        return self._has_deposit_back

    @has_deposit_back.setter
    def has_deposit_back(self, value):
        self._has_deposit_back = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def present_refund_buyer_amount(self):
        return self._present_refund_buyer_amount

    @present_refund_buyer_amount.setter
    def present_refund_buyer_amount(self, value):
        self._present_refund_buyer_amount = value
    @property
    def present_refund_discount_amount(self):
        return self._present_refund_discount_amount

    @present_refund_discount_amount.setter
    def present_refund_discount_amount(self, value):
        self._present_refund_discount_amount = value
    @property
    def present_refund_mdiscount_amount(self):
        return self._present_refund_mdiscount_amount

    @present_refund_mdiscount_amount.setter
    def present_refund_mdiscount_amount(self, value):
        self._present_refund_mdiscount_amount = value
    @property
    def refund_charge_amount(self):
        return self._refund_charge_amount

    @refund_charge_amount.setter
    def refund_charge_amount(self, value):
        self._refund_charge_amount = value
    @property
    def refund_charge_info_list(self):
        return self._refund_charge_info_list

    @refund_charge_info_list.setter
    def refund_charge_info_list(self, value):
        if isinstance(value, list):
            self._refund_charge_info_list = list()
            for i in value:
                if isinstance(i, RefundChargeInfo):
                    self._refund_charge_info_list.append(i)
                else:
                    self._refund_charge_info_list.append(RefundChargeInfo.from_alipay_dict(i))
    @property
    def refund_currency(self):
        return self._refund_currency

    @refund_currency.setter
    def refund_currency(self, value):
        self._refund_currency = value
    @property
    def refund_detail_item_list(self):
        return self._refund_detail_item_list

    @refund_detail_item_list.setter
    def refund_detail_item_list(self, value):
        if isinstance(value, list):
            self._refund_detail_item_list = list()
            for i in value:
                if isinstance(i, TradeFundBill):
                    self._refund_detail_item_list.append(i)
                else:
                    self._refund_detail_item_list.append(TradeFundBill.from_alipay_dict(i))
    @property
    def refund_fee(self):
        return self._refund_fee

    @refund_fee.setter
    def refund_fee(self, value):
        self._refund_fee = value
    @property
    def refund_hyb_amount(self):
        return self._refund_hyb_amount

    @refund_hyb_amount.setter
    def refund_hyb_amount(self, value):
        self._refund_hyb_amount = value
    @property
    def refund_preset_paytool_list(self):
        return self._refund_preset_paytool_list

    @refund_preset_paytool_list.setter
    def refund_preset_paytool_list(self, value):
        if isinstance(value, PresetPayToolInfo):
            self._refund_preset_paytool_list = value
        else:
            self._refund_preset_paytool_list = PresetPayToolInfo.from_alipay_dict(value)
    @property
    def refund_settlement_id(self):
        return self._refund_settlement_id

    @refund_settlement_id.setter
    def refund_settlement_id(self, value):
        self._refund_settlement_id = value
    @property
    def send_back_fee(self):
        return self._send_back_fee

    @send_back_fee.setter
    def send_back_fee(self, value):
        self._send_back_fee = value
    @property
    def store_name(self):
        return self._store_name

    @store_name.setter
    def store_name(self, value):
        self._store_name = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayTradeRefundResponse, self).parse_response_content(response_content)
        if 'buyer_logon_id' in response:
            self.buyer_logon_id = response['buyer_logon_id']
        if 'buyer_open_id' in response:
            self.buyer_open_id = response['buyer_open_id']
        if 'buyer_user_id' in response:
            self.buyer_user_id = response['buyer_user_id']
        if 'fund_change' in response:
            self.fund_change = response['fund_change']
        if 'gmt_refund_pay' in response:
            self.gmt_refund_pay = response['gmt_refund_pay']
        if 'has_deposit_back' in response:
            self.has_deposit_back = response['has_deposit_back']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'present_refund_buyer_amount' in response:
            self.present_refund_buyer_amount = response['present_refund_buyer_amount']
        if 'present_refund_discount_amount' in response:
            self.present_refund_discount_amount = response['present_refund_discount_amount']
        if 'present_refund_mdiscount_amount' in response:
            self.present_refund_mdiscount_amount = response['present_refund_mdiscount_amount']
        if 'refund_charge_amount' in response:
            self.refund_charge_amount = response['refund_charge_amount']
        if 'refund_charge_info_list' in response:
            self.refund_charge_info_list = response['refund_charge_info_list']
        if 'refund_currency' in response:
            self.refund_currency = response['refund_currency']
        if 'refund_detail_item_list' in response:
            self.refund_detail_item_list = response['refund_detail_item_list']
        if 'refund_fee' in response:
            self.refund_fee = response['refund_fee']
        if 'refund_hyb_amount' in response:
            self.refund_hyb_amount = response['refund_hyb_amount']
        if 'refund_preset_paytool_list' in response:
            self.refund_preset_paytool_list = response['refund_preset_paytool_list']
        if 'refund_settlement_id' in response:
            self.refund_settlement_id = response['refund_settlement_id']
        if 'send_back_fee' in response:
            self.send_back_fee = response['send_back_fee']
        if 'store_name' in response:
            self.store_name = response['store_name']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PariticipantDTO import PariticipantDTO


class AlipayUserFlexiblestaffingRiskconsultQueryModel(object):

    def __init__(self):
        self._biz_scene = None
        self._consult_party = None
        self._enterprise_name = None
        self._out_biz_no = None
        self._product_code = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def consult_party(self):
        return self._consult_party

    @consult_party.setter
    def consult_party(self, value):
        if isinstance(value, PariticipantDTO):
            self._consult_party = value
        else:
            self._consult_party = PariticipantDTO.from_alipay_dict(value)
    @property
    def enterprise_name(self):
        return self._enterprise_name

    @enterprise_name.setter
    def enterprise_name(self, value):
        self._enterprise_name = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.consult_party:
            if hasattr(self.consult_party, 'to_alipay_dict'):
                params['consult_party'] = self.consult_party.to_alipay_dict()
            else:
                params['consult_party'] = self.consult_party
        if self.enterprise_name:
            if hasattr(self.enterprise_name, 'to_alipay_dict'):
                params['enterprise_name'] = self.enterprise_name.to_alipay_dict()
            else:
                params['enterprise_name'] = self.enterprise_name
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserFlexiblestaffingRiskconsultQueryModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'consult_party' in d:
            o.consult_party = d['consult_party']
        if 'enterprise_name' in d:
            o.enterprise_name = d['enterprise_name']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EcEmployeeBatchAddSuccessInfo(object):

    def __init__(self):
        self._employee_email = None
        self._employee_id = None
        self._employee_mobile = None
        self._employee_name = None
        self._employee_no = None

    @property
    def employee_email(self):
        return self._employee_email

    @employee_email.setter
    def employee_email(self, value):
        self._employee_email = value
    @property
    def employee_id(self):
        return self._employee_id

    @employee_id.setter
    def employee_id(self, value):
        self._employee_id = value
    @property
    def employee_mobile(self):
        return self._employee_mobile

    @employee_mobile.setter
    def employee_mobile(self, value):
        self._employee_mobile = value
    @property
    def employee_name(self):
        return self._employee_name

    @employee_name.setter
    def employee_name(self, value):
        self._employee_name = value
    @property
    def employee_no(self):
        return self._employee_no

    @employee_no.setter
    def employee_no(self, value):
        self._employee_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.employee_email:
            if hasattr(self.employee_email, 'to_alipay_dict'):
                params['employee_email'] = self.employee_email.to_alipay_dict()
            else:
                params['employee_email'] = self.employee_email
        if self.employee_id:
            if hasattr(self.employee_id, 'to_alipay_dict'):
                params['employee_id'] = self.employee_id.to_alipay_dict()
            else:
                params['employee_id'] = self.employee_id
        if self.employee_mobile:
            if hasattr(self.employee_mobile, 'to_alipay_dict'):
                params['employee_mobile'] = self.employee_mobile.to_alipay_dict()
            else:
                params['employee_mobile'] = self.employee_mobile
        if self.employee_name:
            if hasattr(self.employee_name, 'to_alipay_dict'):
                params['employee_name'] = self.employee_name.to_alipay_dict()
            else:
                params['employee_name'] = self.employee_name
        if self.employee_no:
            if hasattr(self.employee_no, 'to_alipay_dict'):
                params['employee_no'] = self.employee_no.to_alipay_dict()
            else:
                params['employee_no'] = self.employee_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EcEmployeeBatchAddSuccessInfo()
        if 'employee_email' in d:
            o.employee_email = d['employee_email']
        if 'employee_id' in d:
            o.employee_id = d['employee_id']
        if 'employee_mobile' in d:
            o.employee_mobile = d['employee_mobile']
        if 'employee_name' in d:
            o.employee_name = d['employee_name']
        if 'employee_no' in d:
            o.employee_no = d['employee_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFinanceQuotationProtocolAuthorizeCheckModel(object):

    def __init__(self):
        self._open_id = None
        self._protocol_type_list = None
        self._sign_content_list = None
        self._symbols = None
        self._user_id = None

    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def protocol_type_list(self):
        return self._protocol_type_list

    @protocol_type_list.setter
    def protocol_type_list(self, value):
        if isinstance(value, list):
            self._protocol_type_list = list()
            for i in value:
                self._protocol_type_list.append(i)
    @property
    def sign_content_list(self):
        return self._sign_content_list

    @sign_content_list.setter
    def sign_content_list(self, value):
        if isinstance(value, list):
            self._sign_content_list = list()
            for i in value:
                self._sign_content_list.append(i)
    @property
    def symbols(self):
        return self._symbols

    @symbols.setter
    def symbols(self, value):
        if isinstance(value, list):
            self._symbols = list()
            for i in value:
                self._symbols.append(i)
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.protocol_type_list:
            if isinstance(self.protocol_type_list, list):
                for i in range(0, len(self.protocol_type_list)):
                    element = self.protocol_type_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.protocol_type_list[i] = element.to_alipay_dict()
            if hasattr(self.protocol_type_list, 'to_alipay_dict'):
                params['protocol_type_list'] = self.protocol_type_list.to_alipay_dict()
            else:
                params['protocol_type_list'] = self.protocol_type_list
        if self.sign_content_list:
            if isinstance(self.sign_content_list, list):
                for i in range(0, len(self.sign_content_list)):
                    element = self.sign_content_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sign_content_list[i] = element.to_alipay_dict()
            if hasattr(self.sign_content_list, 'to_alipay_dict'):
                params['sign_content_list'] = self.sign_content_list.to_alipay_dict()
            else:
                params['sign_content_list'] = self.sign_content_list
        if self.symbols:
            if isinstance(self.symbols, list):
                for i in range(0, len(self.symbols)):
                    element = self.symbols[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.symbols[i] = element.to_alipay_dict()
            if hasattr(self.symbols, 'to_alipay_dict'):
                params['symbols'] = self.symbols.to_alipay_dict()
            else:
                params['symbols'] = self.symbols
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFinanceQuotationProtocolAuthorizeCheckModel()
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'protocol_type_list' in d:
            o.protocol_type_list = d['protocol_type_list']
        if 'sign_content_list' in d:
            o.sign_content_list = d['sign_content_list']
        if 'symbols' in d:
            o.symbols = d['symbols']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.IoTDeliveryPlan import IoTDeliveryPlan


class AlipayMarketingActivityIotdeliveryQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingActivityIotdeliveryQueryResponse, self).__init__()
        self._plan_detail = None

    @property
    def plan_detail(self):
        return self._plan_detail

    @plan_detail.setter
    def plan_detail(self, value):
        if isinstance(value, IoTDeliveryPlan):
            self._plan_detail = value
        else:
            self._plan_detail = IoTDeliveryPlan.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingActivityIotdeliveryQueryResponse, self).parse_response_content(response_content)
        if 'plan_detail' in response:
            self.plan_detail = response['plan_detail']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceCityfacilitatorVoucherConfirmModel(object):

    def __init__(self):
        self._amount = None
        self._biz_info_ext = None
        self._biz_request_id = None
        self._city_code = None
        self._end_station = None
        self._exchange_ids = None
        self._operate_time = None
        self._out_biz_no = None
        self._quantity = None
        self._seller_id = None
        self._start_station = None
        self._ticket_no = None
        self._ticket_price = None
        self._ticket_type = None
        self._trade_no = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_info_ext(self):
        return self._biz_info_ext

    @biz_info_ext.setter
    def biz_info_ext(self, value):
        self._biz_info_ext = value
    @property
    def biz_request_id(self):
        return self._biz_request_id

    @biz_request_id.setter
    def biz_request_id(self, value):
        self._biz_request_id = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def end_station(self):
        return self._end_station

    @end_station.setter
    def end_station(self, value):
        self._end_station = value
    @property
    def exchange_ids(self):
        return self._exchange_ids

    @exchange_ids.setter
    def exchange_ids(self, value):
        self._exchange_ids = value
    @property
    def operate_time(self):
        return self._operate_time

    @operate_time.setter
    def operate_time(self, value):
        self._operate_time = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def start_station(self):
        return self._start_station

    @start_station.setter
    def start_station(self, value):
        self._start_station = value
    @property
    def ticket_no(self):
        return self._ticket_no

    @ticket_no.setter
    def ticket_no(self, value):
        self._ticket_no = value
    @property
    def ticket_price(self):
        return self._ticket_price

    @ticket_price.setter
    def ticket_price(self, value):
        self._ticket_price = value
    @property
    def ticket_type(self):
        return self._ticket_type

    @ticket_type.setter
    def ticket_type(self, value):
        self._ticket_type = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.biz_info_ext:
            if hasattr(self.biz_info_ext, 'to_alipay_dict'):
                params['biz_info_ext'] = self.biz_info_ext.to_alipay_dict()
            else:
                params['biz_info_ext'] = self.biz_info_ext
        if self.biz_request_id:
            if hasattr(self.biz_request_id, 'to_alipay_dict'):
                params['biz_request_id'] = self.biz_request_id.to_alipay_dict()
            else:
                params['biz_request_id'] = self.biz_request_id
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.end_station:
            if hasattr(self.end_station, 'to_alipay_dict'):
                params['end_station'] = self.end_station.to_alipay_dict()
            else:
                params['end_station'] = self.end_station
        if self.exchange_ids:
            if hasattr(self.exchange_ids, 'to_alipay_dict'):
                params['exchange_ids'] = self.exchange_ids.to_alipay_dict()
            else:
                params['exchange_ids'] = self.exchange_ids
        if self.operate_time:
            if hasattr(self.operate_time, 'to_alipay_dict'):
                params['operate_time'] = self.operate_time.to_alipay_dict()
            else:
                params['operate_time'] = self.operate_time
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.quantity:
            if hasattr(self.quantity, 'to_alipay_dict'):
                params['quantity'] = self.quantity.to_alipay_dict()
            else:
                params['quantity'] = self.quantity
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.start_station:
            if hasattr(self.start_station, 'to_alipay_dict'):
                params['start_station'] = self.start_station.to_alipay_dict()
            else:
                params['start_station'] = self.start_station
        if self.ticket_no:
            if hasattr(self.ticket_no, 'to_alipay_dict'):
                params['ticket_no'] = self.ticket_no.to_alipay_dict()
            else:
                params['ticket_no'] = self.ticket_no
        if self.ticket_price:
            if hasattr(self.ticket_price, 'to_alipay_dict'):
                params['ticket_price'] = self.ticket_price.to_alipay_dict()
            else:
                params['ticket_price'] = self.ticket_price
        if self.ticket_type:
            if hasattr(self.ticket_type, 'to_alipay_dict'):
                params['ticket_type'] = self.ticket_type.to_alipay_dict()
            else:
                params['ticket_type'] = self.ticket_type
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceCityfacilitatorVoucherConfirmModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'biz_info_ext' in d:
            o.biz_info_ext = d['biz_info_ext']
        if 'biz_request_id' in d:
            o.biz_request_id = d['biz_request_id']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'end_station' in d:
            o.end_station = d['end_station']
        if 'exchange_ids' in d:
            o.exchange_ids = d['exchange_ids']
        if 'operate_time' in d:
            o.operate_time = d['operate_time']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'quantity' in d:
            o.quantity = d['quantity']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'start_station' in d:
            o.start_station = d['start_station']
        if 'ticket_no' in d:
            o.ticket_no = d['ticket_no']
        if 'ticket_price' in d:
            o.ticket_price = d['ticket_price']
        if 'ticket_type' in d:
            o.ticket_type = d['ticket_type']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.StandardConditionInfo import StandardConditionInfo


class StandardInfo(object):

    def __init__(self):
        self._consume_mode = None
        self._expense_type_sub_category = None
        self._open_rule_id = None
        self._outer_source_id = None
        self._payment_policy = None
        self._standard_condition_info_list = None
        self._standard_desc = None
        self._standard_id = None
        self._standard_name = None

    @property
    def consume_mode(self):
        return self._consume_mode

    @consume_mode.setter
    def consume_mode(self, value):
        self._consume_mode = value
    @property
    def expense_type_sub_category(self):
        return self._expense_type_sub_category

    @expense_type_sub_category.setter
    def expense_type_sub_category(self, value):
        self._expense_type_sub_category = value
    @property
    def open_rule_id(self):
        return self._open_rule_id

    @open_rule_id.setter
    def open_rule_id(self, value):
        self._open_rule_id = value
    @property
    def outer_source_id(self):
        return self._outer_source_id

    @outer_source_id.setter
    def outer_source_id(self, value):
        self._outer_source_id = value
    @property
    def payment_policy(self):
        return self._payment_policy

    @payment_policy.setter
    def payment_policy(self, value):
        self._payment_policy = value
    @property
    def standard_condition_info_list(self):
        return self._standard_condition_info_list

    @standard_condition_info_list.setter
    def standard_condition_info_list(self, value):
        if isinstance(value, list):
            self._standard_condition_info_list = list()
            for i in value:
                if isinstance(i, StandardConditionInfo):
                    self._standard_condition_info_list.append(i)
                else:
                    self._standard_condition_info_list.append(StandardConditionInfo.from_alipay_dict(i))
    @property
    def standard_desc(self):
        return self._standard_desc

    @standard_desc.setter
    def standard_desc(self, value):
        self._standard_desc = value
    @property
    def standard_id(self):
        return self._standard_id

    @standard_id.setter
    def standard_id(self, value):
        self._standard_id = value
    @property
    def standard_name(self):
        return self._standard_name

    @standard_name.setter
    def standard_name(self, value):
        self._standard_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.consume_mode:
            if hasattr(self.consume_mode, 'to_alipay_dict'):
                params['consume_mode'] = self.consume_mode.to_alipay_dict()
            else:
                params['consume_mode'] = self.consume_mode
        if self.expense_type_sub_category:
            if hasattr(self.expense_type_sub_category, 'to_alipay_dict'):
                params['expense_type_sub_category'] = self.expense_type_sub_category.to_alipay_dict()
            else:
                params['expense_type_sub_category'] = self.expense_type_sub_category
        if self.open_rule_id:
            if hasattr(self.open_rule_id, 'to_alipay_dict'):
                params['open_rule_id'] = self.open_rule_id.to_alipay_dict()
            else:
                params['open_rule_id'] = self.open_rule_id
        if self.outer_source_id:
            if hasattr(self.outer_source_id, 'to_alipay_dict'):
                params['outer_source_id'] = self.outer_source_id.to_alipay_dict()
            else:
                params['outer_source_id'] = self.outer_source_id
        if self.payment_policy:
            if hasattr(self.payment_policy, 'to_alipay_dict'):
                params['payment_policy'] = self.payment_policy.to_alipay_dict()
            else:
                params['payment_policy'] = self.payment_policy
        if self.standard_condition_info_list:
            if isinstance(self.standard_condition_info_list, list):
                for i in range(0, len(self.standard_condition_info_list)):
                    element = self.standard_condition_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.standard_condition_info_list[i] = element.to_alipay_dict()
            if hasattr(self.standard_condition_info_list, 'to_alipay_dict'):
                params['standard_condition_info_list'] = self.standard_condition_info_list.to_alipay_dict()
            else:
                params['standard_condition_info_list'] = self.standard_condition_info_list
        if self.standard_desc:
            if hasattr(self.standard_desc, 'to_alipay_dict'):
                params['standard_desc'] = self.standard_desc.to_alipay_dict()
            else:
                params['standard_desc'] = self.standard_desc
        if self.standard_id:
            if hasattr(self.standard_id, 'to_alipay_dict'):
                params['standard_id'] = self.standard_id.to_alipay_dict()
            else:
                params['standard_id'] = self.standard_id
        if self.standard_name:
            if hasattr(self.standard_name, 'to_alipay_dict'):
                params['standard_name'] = self.standard_name.to_alipay_dict()
            else:
                params['standard_name'] = self.standard_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = StandardInfo()
        if 'consume_mode' in d:
            o.consume_mode = d['consume_mode']
        if 'expense_type_sub_category' in d:
            o.expense_type_sub_category = d['expense_type_sub_category']
        if 'open_rule_id' in d:
            o.open_rule_id = d['open_rule_id']
        if 'outer_source_id' in d:
            o.outer_source_id = d['outer_source_id']
        if 'payment_policy' in d:
            o.payment_policy = d['payment_policy']
        if 'standard_condition_info_list' in d:
            o.standard_condition_info_list = d['standard_condition_info_list']
        if 'standard_desc' in d:
            o.standard_desc = d['standard_desc']
        if 'standard_id' in d:
            o.standard_id = d['standard_id']
        if 'standard_name' in d:
            o.standard_name = d['standard_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingToolFengdieSitesConfirmModel(object):

    def __init__(self):
        self._activity_id = None
        self._offline_time = None
        self._operator = None
        self._space_id = None
        self._status = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def offline_time(self):
        return self._offline_time

    @offline_time.setter
    def offline_time(self, value):
        self._offline_time = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def space_id(self):
        return self._space_id

    @space_id.setter
    def space_id(self, value):
        self._space_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.offline_time:
            if hasattr(self.offline_time, 'to_alipay_dict'):
                params['offline_time'] = self.offline_time.to_alipay_dict()
            else:
                params['offline_time'] = self.offline_time
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.space_id:
            if hasattr(self.space_id, 'to_alipay_dict'):
                params['space_id'] = self.space_id.to_alipay_dict()
            else:
                params['space_id'] = self.space_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingToolFengdieSitesConfirmModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'offline_time' in d:
            o.offline_time = d['offline_time']
        if 'operator' in d:
            o.operator = d['operator']
        if 'space_id' in d:
            o.space_id = d['space_id']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class StdPublicBindAccount(object):

    def __init__(self):
        self._agreement_id = None
        self._app_id = None
        self._bind_account_no = None
        self._display_name = None
        self._from_user_id = None
        self._open_id = None
        self._real_name = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def app_id(self):
        return self._app_id

    @app_id.setter
    def app_id(self, value):
        self._app_id = value
    @property
    def bind_account_no(self):
        return self._bind_account_no

    @bind_account_no.setter
    def bind_account_no(self, value):
        self._bind_account_no = value
    @property
    def display_name(self):
        return self._display_name

    @display_name.setter
    def display_name(self, value):
        self._display_name = value
    @property
    def from_user_id(self):
        return self._from_user_id

    @from_user_id.setter
    def from_user_id(self, value):
        self._from_user_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def real_name(self):
        return self._real_name

    @real_name.setter
    def real_name(self, value):
        self._real_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_id:
            if hasattr(self.agreement_id, 'to_alipay_dict'):
                params['agreement_id'] = self.agreement_id.to_alipay_dict()
            else:
                params['agreement_id'] = self.agreement_id
        if self.app_id:
            if hasattr(self.app_id, 'to_alipay_dict'):
                params['app_id'] = self.app_id.to_alipay_dict()
            else:
                params['app_id'] = self.app_id
        if self.bind_account_no:
            if hasattr(self.bind_account_no, 'to_alipay_dict'):
                params['bind_account_no'] = self.bind_account_no.to_alipay_dict()
            else:
                params['bind_account_no'] = self.bind_account_no
        if self.display_name:
            if hasattr(self.display_name, 'to_alipay_dict'):
                params['display_name'] = self.display_name.to_alipay_dict()
            else:
                params['display_name'] = self.display_name
        if self.from_user_id:
            if hasattr(self.from_user_id, 'to_alipay_dict'):
                params['from_user_id'] = self.from_user_id.to_alipay_dict()
            else:
                params['from_user_id'] = self.from_user_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.real_name:
            if hasattr(self.real_name, 'to_alipay_dict'):
                params['real_name'] = self.real_name.to_alipay_dict()
            else:
                params['real_name'] = self.real_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = StdPublicBindAccount()
        if 'agreement_id' in d:
            o.agreement_id = d['agreement_id']
        if 'app_id' in d:
            o.app_id = d['app_id']
        if 'bind_account_no' in d:
            o.bind_account_no = d['bind_account_no']
        if 'display_name' in d:
            o.display_name = d['display_name']
        if 'from_user_id' in d:
            o.from_user_id = d['from_user_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'real_name' in d:
            o.real_name = d['real_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransGroupfundsUserbillsQueryModel(object):

    def __init__(self):
        self._batch_nos = None
        self._current_user_id = None

    @property
    def batch_nos(self):
        return self._batch_nos

    @batch_nos.setter
    def batch_nos(self, value):
        if isinstance(value, list):
            self._batch_nos = list()
            for i in value:
                self._batch_nos.append(i)
    @property
    def current_user_id(self):
        return self._current_user_id

    @current_user_id.setter
    def current_user_id(self, value):
        self._current_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_nos:
            if isinstance(self.batch_nos, list):
                for i in range(0, len(self.batch_nos)):
                    element = self.batch_nos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.batch_nos[i] = element.to_alipay_dict()
            if hasattr(self.batch_nos, 'to_alipay_dict'):
                params['batch_nos'] = self.batch_nos.to_alipay_dict()
            else:
                params['batch_nos'] = self.batch_nos
        if self.current_user_id:
            if hasattr(self.current_user_id, 'to_alipay_dict'):
                params['current_user_id'] = self.current_user_id.to_alipay_dict()
            else:
                params['current_user_id'] = self.current_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransGroupfundsUserbillsQueryModel()
        if 'batch_nos' in d:
            o.batch_nos = d['batch_nos']
        if 'current_user_id' in d:
            o.current_user_id = d['current_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataRiskRtopobtsregQueryModel(object):

    def __init__(self):
        self._rowkeys = None

    @property
    def rowkeys(self):
        return self._rowkeys

    @rowkeys.setter
    def rowkeys(self, value):
        self._rowkeys = value


    def to_alipay_dict(self):
        params = dict()
        if self.rowkeys:
            if hasattr(self.rowkeys, 'to_alipay_dict'):
                params['rowkeys'] = self.rowkeys.to_alipay_dict()
            else:
                params['rowkeys'] = self.rowkeys
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataRiskRtopobtsregQueryModel()
        if 'rowkeys' in d:
            o.rowkeys = d['rowkeys']
        return o


